<?php

/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * @package openEngine
 * @author Stephan Raabe
 */

class DataBase
{
	private $conn;
	private $miss;
	private $hits;
	private $bindcount;
	private $querystack;
	private $querycache;
	private $usecache;
	private $set;
	private $site_encoding;

	/**
	 * Konstruktor
	 *
	 * @param string $db_server Datenbank-Server
	 * @param string $db_user Datenbank-Benutzer
	 * @param string $db_password Passwort
	 * @param string $db_name Tabellen-Name
	 * @param string $site_encoding Kodierung des Datenbank-Servers
	 * @return DataBase
	 */
	public function DataBase($db_server, $db_user, $db_password, $db_name, $site_encoding)
	{
		global $oe_set;
		$this->conn = mysql_connect($db_server, $db_user, $db_password);
		mysql_select_db($db_name);
		if ($site_encoding == "utf-8")
		{
			mysql_query("SET NAMES utf8");
		}
		$this->site_encoding = $site_encoding;
		$this->usecache = true;
		$this->miss = 0;
		$this->hits = 0;
		$this->bindcount = 0;
		$this->set = $oe_set;
		$this->querystack = array();
		$this->querycache = array();
	}

	/**
	 * Ersetzt die Datenbank-Parameter durch die entsprechenden Were, die durch das $param Array �bergeben werden.
	 *
	 * @param string $query Datenbank Query
	 * @param array $param Array mit Parametern
	 * @param bool $striptags	false: Tags werden nicht entfernt
	 * 							true: Tags werden entfernt
	 * @return string
	 */
	private function bind($query, $param = array(),$striptags = false)
	{
		$regex = '/[0-9.]*[eE][0-9]+/';
		foreach($param as $key => $value)
		{
			if ((is_numeric($value)) AND (!preg_match($regex, $value)))
			{
			}
			else if(is_string($value))
			{
				if ($striptags)
				{
					$value = StringFilter::filterTagsWhitelist($key,$value);
				}
				$value = StringFilter::replaceEntitiesWhitelist($key,$value,$this->site_encoding);
				$value = StringFilter::stripSlash($value);
				$value = mysql_real_escape_string($value, $this->conn);
				$value = addcslashes($value, "()+-/?@;");
				$value = "'".$value."'";
			}
			else if(is_null($value))
			{
				$value = "NULL";
			}
			else
			{
				die("Permission denied.");
			}
			$query = str_replace(":".$key, $value, $query);
		}
		$this->bindcount++;
		if (isset ($_SESSION["debug"]) AND $_SESSION["debug"] == true ){
			$backtrace = debug_backtrace();
			$file0 = $backtrace[0]["file"];
			$func0 = $backtrace[0]["function"];
			$line0 = $backtrace[0]["line"];
			$file1 = $backtrace[1]["file"];
			$func1 = $backtrace[1]["function"];
			$line1 = $backtrace[1]["line"];
			$file2 = $backtrace[2]["file"];
			$func2 = $backtrace[2]["function"];
			$line2 = $backtrace[2]["line"];
			array_push($this->querystack,"\n>($file2:$func2:$line2)\n>($file1:$func1:$line1)\n>($file0:$func0:$line0)\n".$query);
		}
		return $query;
	}

	/**
	 * F�hrt den Query-Cache aus.
	 *
	 * @param string $query Datenbank Query
	 * @return array Ergebnis
	 */
	private function exec($query)
	{
		static $querycache = array();
		static $hit = 0;
		static $missed = 0;
		if ($this->usecache == true)
		{
			$hash = md5($query);
			if (isset($querycache[$hash]))
			{
				$row = unserialize($querycache[$hash]);
				$this->querycache = $querycache;
				$type = "Cache";
				$hit++;
			} 
			else 
			{
				$result = mysql_query($query, $this->conn);
				$row = mysql_fetch_assoc($result);
				$querycache[$hash] = serialize($row);
				$type = "Query";
				$missed++;
			}
		} 
		else 
		{
			$result = mysql_query($query, $this->conn);
			$row = mysql_fetch_assoc($result);
			$missed++;
		}

		if (isset ($_SESSION["debug"]) AND $_SESSION["debug"] == true )
		{
			$this->hits = $hit;
			$this->miss = $missed;
			@$this->querystack[$this->bindcount-2] .= "\n<strong>Executed ($type):</strong>\n".$query;
		}
		return $row;
	}

	/**
	 * F�hrt ein SELECT Query aus. 
	 *
	 * @param string $query Datenbank-Query
	 * @param array $param Array mit Parametern
	 * @return array Ergebnisse der Abfrage
	 */
	public function select($query, $param = array())
	{
		$query = $this->bind($query, $param);
		$result = mysql_query($query, $this->conn);
		$table = array();

		while($row = mysql_fetch_assoc($result))
		{
			array_push($table, $row);
		}
		return $table;
	}

	/**
	 * F�hrt eine individuelle Abfrage der Datenbank aus. 
	 * Es werden keine Query-Ersetzungen durchgef�hrt.
	 *
	 * @param string $query Datenbank-Query
	 * @return array Ergebnisse der Abfrage
	 */
	public function search($query)
	{
		$result = mysql_query($query, $this->conn);
		$table = array();

		while($row = mysql_fetch_assoc($result))
		{
			array_push($table, $row);
		}
		return $table;
	}

	/**
	 * F�hrt ein SELECT Query aus und gibt ein MySQL Resultset zur�ck. 
	 *
	 * @param string $query Datenbank-Query
	 * @param array $param Array mit Parametern
	 * @return MySQL Resultset Ergebnisse der Abfrage
	 */
	public function selectResult($query, $param = array())
	{
		$query = $this->bind($query, $param);
		return mysql_query($query, $this->conn);
	}

	/**
	 * Z�hlt die Ergebnisse des Datenbank-Query.
	 *
	 * @param string $query Datenbank-Query
	 * @param array $param Array mit Paramatern
	 * @return int Anzahl der Ergebnisse
	 */
	public function count($query, $param = array())
	{
		$query = $this->bind($query, $param);
		$result = mysql_query($query, $this->conn);
		return mysql_num_rows($result);
	}

	/**
	 * F�hrt eine Datenbank-Abfrage aus und gibt genau ein Ergebnis zur�ck.
	 *
	 * @param string $query Datenbank-Query
	 * @param array $param Array mit Parametern
	 * @return array Ergebnis der Abfrage
	 */
	public function row($query, $param = array())
	{
		$query = $this->bind($query, $param);
		$row = $this->exec($query);
		return $row;
	}

	/**
	 * Aktualisiert Werte der Datenbank
	 *
	 * @param string $query Datenbank-Query
	 * @param array $param Array mit Paramatern
	 * @param bool $strip_tags	false: Tags werden nicht entfernt
	 * 							true: Tags werden entfernt
	 */
	public function update($query, $param = array(), $strip_tags = true)
	{
		$query = $this->bind($query, $param, $strip_tags);
		mysql_query($query, $this->conn);
	}

	/**
	 * L�scht einen Datenbank-Eintrag
	 *
	 * @param string $query Datenbank-Query
	 * @param array $param Array mit Parametern
	 */
	public function delete($query, $param = array())
	{
		$query = $this->bind($query, $param);
		mysql_query($query, $this->conn);
	}

	/**
	 * F�gt einen neuen Datenbankeintrag hinzu.
	 *
	 * @param string $query Datenbank-Query
	 * @param array $param Array mit Parametern
	 * @return int ID des neuen Datenbankeintrags
	 */
	public function insert($query, $param = array())
	{
		$query = $this->bind($query, $param, true);
		mysql_query($query, $this->conn);
		return mysql_insert_id($this->conn);
	}

	/**
	 * �ffnet eine Datenbank-Verbindung.
	 *
	 * @param string $db_server Datenbank-Server
	 * @param string $db_user Datenbank-Benutzer
	 * @param string $db_password Passwort
	 * @param string $db_name Tabellenname
	 * @param string $site_encoding Kodierung der Datenbank
	 * @return MySQL Ressource
	 */
	public function connectDB($db_server, $db_user, $db_password, $db_name, $site_encoding)
	{
		$link = mysql_pconnect($db_server, $db_user, $db_password) or die("openEngine ERROR: Choose <a href='system/setup/index.php'>Installation</a> or check your current system");
		mysql_select_db($db_name) or die("openEngine ERROR: Choose <a href='system/setup/index.php'>Installation</a> or check your current system");
		if ($site_encoding == "utf-8")
		{
			mysql_query("SET NAMES utf8");
		}
		return $link;
	}

	/**
	 * Schliesst die Datenbank-Verbindung.
	 *
	 * @param MySQL Ressource $link
	 */
	public function closeDB($link)
	{
		mysql_close($link);
	}
}
?>