<?php

/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * @package openEngine
 * @author Stephan Raabe
 */

class Page
{
	/**
	* Datenbank
	*
	* @access private
	*/	
	private $db;

	/**
	* Tabellen Praefix
	*
	* @var    string
	* @access private
	*/	
	private $prefix;

	/**
	* Settings
	*
	* @access private
	*/	
	private $set;

	/**
	* Benutzer
	*
	* @access private
	*/	
	private $user;
	
	function Page()
	{
		global $oe_db,$db_praefix,$oe_set,$oe_user;
		$this->db = &$oe_db;
		$this->prefix = $db_praefix;
		$this->set = $oe_set;
		$this->user = $oe_user;
	}
	
	public function getInput()
	{
		if (isset($_GET["id"]))
		{
			$input = $_GET["id"];
		}
		else
		{
			$input = $this->set->getSiteHome();
		}
		return $input;
	}
	
	public function getPage($page_path)
	{
		$account_status = 0;
		$access = "";
		if (empty($_GET["export"]))
		{
			$account_status = $_SESSION["account_group"];
			if ($_SESSION["account_group"] == 1)
			{
				$account_access = $_SESSION["account_access"];
				$access = " AND (page_access <= :account_access)";
				$param = array("page_path" => $page_path,"account_status" => $account_status,"account_access" => $account_access);
			}
			else
			{
				$param = array("page_path" => $page_path,"account_status" => $account_status);
			}
		}
		else
		{
			$param = array("page_path" => $page_path,"account_status" => $account_status);
		}
		$access .= " AND (page_status <> 3)";
		$query = "SELECT * FROM ".$this->prefix."page WHERE (page_path = :page_path) AND (page_status <= :account_status) $access";
		$page = $this->db->row($query,$param);
		if (sizeof($page) > 1)
		{
			$page["page_rows"] = 1;
		}
		else
		{
			$page["page_rows"] = 0;
		}
		if (isset($_GET["template"]))
		{
			$param = array("template_name" => $_GET["template"]);
			$query = "SELECT template_key FROM ".$this->prefix."template WHERE template_name = :template_name";
			if ($this->db->row($query,$param) == 1)
			{
				$page["page_template"] = $_GET["template"];
			}
		}
		return $page;		
	}
	
	public function getPageKey($page_key,$perm = true,$hidetext = false)
	{
		$account_status = 0;
		$access = "";
		if (empty($_GET["export"]))
		{
			$account_status = $_SESSION["account_group"];
			if ($_SESSION["account_group"] == 1)
			{
				$account_access = $_SESSION["account_access"];
				$access = " AND (page_access <= :account_access)";
				$param = array("page_key" => $page_key,"account_status" => $account_status,"account_access" => $account_access);
			}
			else
			{
				$param = array("page_key" => $page_key,"account_status" => $account_status);
			}
		}
		else
		{
			$param = array("page_key" => $page_key,"account_status" => $account_status);
		}
		if ($perm)
		{
			$access .= " AND (page_status <> 3)";
		}
		if ($hidetext)
		{
			$query = "SELECT page_key,treelink_key,page_template,page_path,page_extern,page_parent,page_navigation,page_title,page_headline,page_access,page_lang,page_start,page_main,page_hide,page_att1,page_att2 FROM ".$this->prefix."page WHERE (page_key = :page_key) AND (page_status <= :account_status) $access";
		}
		else 
		{
			$query = "SELECT * FROM ".$this->prefix."page WHERE (page_key = :page_key) AND (page_status <= :account_status) $access";
		}
		$page = $this->db->row($query,$param);
		if (sizeof($page) > 1)
		{
			$page["page_rows"] = 1;
		}
		else
		{
			$page["page_rows"] = 0;
		}		
		if (isset($_GET["template"]))
		{
			$page["page_template"] = $_GET["template"];
		}
		return $page;
	}
	
	public function getPath($page)
	{
		$path = array();
		$external = 0;
		if (isset($_GET["export"]))
		{
			if ($page["page_extern"] != "")
			{
				$external = 1;
				$path_url = $page["page_extern"];
			}
			else 
			{
				$path_url = "website.php?id=".$page["page_path"];
			}			
		}
		else 
		{
			if (($page["page_extern"] != "") && (($_SESSION["account_group"] < 2) || ((isset($_SESSION["preview"])) && ($_SESSION["preview"] == 1))))
			{
				$external = 1;
				$path_url = $page["page_extern"];
			}
			else 
			{
				$path_url = "website.php?id=".$page["page_path"];
			}
		}
		$path[0] = array("current" => "1","external" => "0","page_lang" => $page["page_lang"],"page_key" => $page["page_key"],"page_headline" => $page["page_headline"],"page_navigation" => $page["page_navigation"],"page_title" => $page["page_title"],"page_path" => $path_url,"page_template" => $page["page_template"],"page_exportfolder" => $page["page_exportfolder"],"page_hide" => $page["page_hide"]);
		$counter = 1;
		$page_parent = $page["page_parent"];
		while ($page_parent != 0)
		{
			$external = 0;
			$param = array("page_key" => $page_parent);
			$query = "SELECT page_key,page_hide,page_path,page_extern,page_parent,page_lang,page_headline,page_navigation,page_title,page_template,page_extern,page_exportfolder FROM ".$this->prefix."page WHERE (page_key = :page_key)";
			$row = $this->db->row($query,$param);
			if (isset($_GET["export"]))
			{
				if ($row["page_extern"] != "")
				{
					$external = 1;
					$link_path = $row["page_extern"];
				}
				else 
				{
					$link_path = "website.php?id=".$row["page_path"];
				}
			}
			else 
			{
		        if (($row["page_extern"] != "") && (($_SESSION["account_group"] < 2) || ((isset($_SESSION["preview"])) && ($_SESSION["preview"] == 1))))
		        {
					$link_path = $row["page_extern"];
					$external = 1;
		        }
		        else
	    	    {
					$link_path = "website.php?id=".$row["page_path"];
				}
			}
			$path[$counter] = array("current" => "0","external" => $external,"page_lang" => $row["page_lang"],"page_key" => $row["page_key"],"page_headline" => $row["page_headline"],"page_navigation" => $row["page_navigation"],"page_title" => $row["page_title"],"page_path" => $link_path,"page_template" => $row["page_template"],"page_exportfolder" => $row["page_exportfolder"],"page_hide" => $row["page_hide"]);				
			$counter++;
			$page_parent = $row["page_parent"];
		}
		$path = array_reverse($path);
		return $path;
	}
	
	public function getHomepage($page_key)
	{
		$account_status = 0;
		$access = "";
		if (empty($_GET["export"]))
		{
			$account_status = $_SESSION["account_group"];
			if ($_SESSION["account_group"] == 1)
			{
				$account_access = $_SESSION["account_access"];
				$access = " AND (page_access <= :account_access)";
				$param = array("page_key" => $page_key,"account_status" => $account_status,"account_access" => $account_access);
			}
			else
			{
				$param = array("page_key" => $page_key,"account_status" => $account_status);
			}
		}
		else
		{
			$param = array("page_key" => $page_key,"account_status" => $account_status);
		}
		$access .= " AND (page_status <> 3)";
		$query = "SELECT * FROM ".$this->prefix."page WHERE (page_key = :page_key) AND (page_status <= :account_status) $access";
		return $this->db->row($query,$param);
	}	

	public function getHomepages()
	{
		$account_status = 0;
		$access = "";
		if (empty($_GET["export"]))
		{
			$account_status = $_SESSION["account_group"];
			if ($_SESSION["account_group"] == 1)
			{
				$account_access = $_SESSION["account_access"];
				$access = " AND (page_access <= :account_access)";
				$param = array("account_status" => $account_status,"page_access" => $account_access);
			}
			else
			{
				$param = array("account_status" => $account_status);
			}
		}
		else
		{
			$param = array("account_status" => $account_status);
		}
		$access .= " AND (page_status <> 3)";
		$query = "SELECT * FROM ".$this->prefix."page WHERE page_parent = 0 AND (page_status <= :account_status) $access";
		return $this->db->select($query,$param);
	}
	
	public function getBlockCount($page_key)
	{
		$param = array("page_key" => $page_key);
		$query = "SELECT page_key FROM ".$this->prefix."stage WHERE page_key = :page_key";
		return $this->db->count($query,$param);
	}
	
	public function writeRequire($formName,$fields)
	{
		global $admin_lang;
		echo "function checkInput() {";
		$strg = "if (";
		$counter = 0;
		foreach ($fields as $field)
		{
			$counter = $counter + 1;
			$strg = $strg. "(document.".$formName.".".$field.".value != '')";
			if ($counter < sizeof($fields))
			{
				$strg = $strg." && ";
			}
		}
		$strg = $strg.")";
		echo $strg;
		echo "{ document.".$formName.".submit(); } else { alert ('".$admin_lang["profile"][3]."') }}";
	}
	
	public function getStartsite()
	{
		$query = "SELECT * FROM ".$this->prefix."page WHERE page_main = 1";
		return $this->db->row($query);
	}
	
	public function getLogString()
	{
		$log_str = "";
		if (isset($_GET["em"]))
		{
			$log_str .= "&em=".$_GET["em"];
			if (isset($_GET["pw"]))
			{
				$log_str .= "&pw=".$_GET["pw"];
			}
		}
		return $log_str;
	}
	
	public function getFilepoolKey($k)
	{
		$param = array("folder_key" => $k);
		$query = "SELECT * FROM ".$this->prefix."asset inner join ".$this->prefix."filepool on (".$this->prefix."filepool.folder_key = ".$this->prefix."asset.folder_key) WHERE ".$this->prefix."asset.folder_key = :folder_key ORDER BY asset_filename";
		return $this->db->select($query,$param);
	}
	
	public function getFilepool()
	{
		$query = "SELECT * FROM ".$this->prefix."asset inner join ".$this->prefix."filepool on (".$this->prefix."filepool.folder_key = ".$this->prefix."asset.folder_key) ORDER BY asset_filename";
		return $this->db->select($query);
	}
	
	public function translatePath($page_file)
	{
		return "website.php?id=".$page_file;
	}
	
	public function getAsset($an,$f)
	{
		$param = array("file_name" => $an);
		$query = "SELECT * FROM ".$this->prefix."asset inner join ".$this->prefix."filepool on (".$this->prefix."filepool.folder_key = ".$this->prefix."asset.folder_key) WHERE asset_filename = :file_name";
		$resArr = $this->db->row($query,$param);
		if (sizeof($resArr) > 1)
		{
			return $resArr[$f];
		}
		else
		{
			return "";		
		}
	}
	
	public function getLang($page_lang)
	{
		if ($page_lang != "")
		{
			$lang = "/".$page_lang;
		}
		else
		{
			$lang = "";
		}
		return $lang;
	}
	
	public function getTemplate($page)
	{
		if (isset($_GET["template"]))
	   	{
	  		$pos = strpos($_GET["template"], "03_admin");
			if ($pos === false) 
			{
		  		$template = $_GET["template"];
			}
			else
			{
				die();
			}
	   	}
	   	else
	   	{
	   		$template = $page["page_template"];
	   	}
	   	return $template;		
	}
	
	public function getTemplateSelect($template_name)
	{
		$param = array("template_name" => $template_name);
		$query = "SELECT template_select FROM ".$this->prefix."template WHERE template_name = :template_name";
		$resArr = $this->db->row($query,$param);
		return $resArr["template_select"];
	}

	public function getTemplateInfo($template)
	{
		$param = array("template_name" => $template);
	   	$query = "SELECT template_hide FROM ".$this->prefix."template WHERE template_name = :template_name";
		return $this->db->row($query,$param);
	}
	
	public function getTemplateSource($template)
	{
		$param = array("template" => $template);
        $query = "SELECT template_source from ".$this->prefix."template WHERE template_name = :template";
		return $this->db->row($query,$param);		
	}
	
	public function getAttributes()
	{
		$query = "SELECT * FROM ".$this->prefix."attribute ORDER BY att_name";
		return $this->db->select($query);
	}

	public function updateStatistic($page)
	{
		$page_key = $page["page_key"];
		$page_count = $page["page_count"] + 1;
		$param = array("page_count" => $page_count, "page_key" => $page_key);
		$query = "UPDATE ".$this->prefix."page SET page_count = :page_count WHERE page_key = :page_key";
		$this->db->update($query,$param);
	}

	public function getTemplates()
	{
		$query = "SELECT * FROM ".$this->prefix."template where template_include = 0 ORDER BY template_short";
		return $this->db->select($query);
	}
	
	public function getCompleteUrl()
	{
		if (isset($_SERVER["PHP_SELF"]))
		{
			$url_complete = $_SERVER["PHP_SELF"];
		}
		else
		{
			$url_complete = "";
		}
		if (isset($_SERVER["QUERY_STRING"]))
		{
			$url_complete .= "?".$_SERVER["QUERY_STRING"];
		}
		else
		{
			$url_complete .= "";
		}
		return $url_complete;
	} 	
	
	public function checkUrl()
	{
		$url_complete = htmlentities($this->getCompleteUrl());
		$pos1 = strpos ($url_complete, "<");
		$pos2 = strpos ($url_complete, ">");
		$pos3 = strpos ($url_complete, "%3c");
		$pos4 = strpos ($url_complete, "%3e");
		if (($pos1 === false) && ($pos2 === false) && ($pos3 === false) && ($pos4 === false))
		{ 
		} 
		else 
		{ 
			Header("Location: website.php");			
		}
	}
	
	public function getParentPages($key)
	{
		$pArr = Array();
		$pKey = $this->getPageKey($key,true,true);
		$k = $pKey["page_key"];
		$p = $pKey["page_parent"];
		array_push($pArr,$k);
		while ($p != 0)
		{
			$pKey = $this->getPageKey($p,true,true);
			if (isset($pKey["page_key"]))
			{
				$k = $pKey["page_key"];
				$p = $pKey["page_parent"];
				array_push($pArr,$k);
			}
			else 
			{
				$p = 0;
			}		
		}
		$pArr = array_reverse($pArr);
		return $pArr;
	}

	public function getLangs()
	{
		$query = "SELECT * FROM ".$this->prefix."language ORDER BY lang_short";
		return $this->db->select($query);
	}

	public function getLangName($str)
	{
		$ret = "";
		$param = array("lang_short" => $str);
		$query = "SELECT lang_key,lang_name FROM ".$this->prefix."language WHERE lang_short = :lang_short";
		$retArr = $this->db->row($query,$param);
		if (sizeof($retArr) > 1)
		{
			$ret = $retArr["lang_name"];
		}
		return $ret;
	}
	
	public function getTreeLinks($k)
	{
		$treeArr = array();
		$pA = $this->getPageKey($k,true,true);
		$treelink_key = $pA["treelink_key"];
		$account_status = 0;
		$access = "";
		if (empty($_GET["export"]))
		{
			$account_status = $_SESSION["account_group"];
			if ($_SESSION["account_group"] == 1)
			{
				$account_access = $_SESSION["account_access"];
				$access = " AND (page_access <= :account_access)";
				$param = array("treelink_key" => $treelink_key,"account_status" => $account_status,"account_access" => $account_access);
			}
			else
			{
				$param = array("treelink_key" => $treelink_key,"account_status" => $account_status);
			}
		}
		else
		{
			$param = array("treelink_key" => $treelink_key,"account_status" => $account_status);
		}
		$access .= " AND (page_status <> 3)";	
		if ($treelink_key == 0)
		{
			$link_path = "website.php?id=".$pA["page_path"];
			$hPArr = $this->getParentPages($pA["page_key"]);
			$hp = $this->getPageKey($hPArr[0],true,true);
			$treeArr[0] = array("current" => "1","page_lang" => $hp["page_lang"],"page_key" => $pA["page_key"],"page_headline" => $pA["page_headline"],"page_navigation" => $pA["page_navigation"],"page_title" => $pA["page_title"],"page_path" => $link_path,"page_template" => $pA["page_template"]);
		}
		else
		{
			$query = "SELECT * FROM ".$this->prefix."page WHERE treelink_key = :treelink_key AND (page_status <= :account_status) $access";
			$resArr = $this->db->select($query,$param);
			$counter = 0;
			foreach ($resArr as $row)
			{
				$link_path = "website.php?id=".$row["page_path"];
				$hPArr = $this->getParentPages($row["page_key"]);
				$hp = $this->getPageKey($hPArr[0],true,true);
				if ($row["page_key"] == $pA["page_key"])
				{
					$treeArr[$counter] = array("current" => "1","page_lang" => $hp["page_lang"],"page_key" => $row["page_key"],"page_headline" => $row["page_headline"],"page_navigation" => $row["page_navigation"],"page_title" => $row["page_title"],"page_path" => $link_path,"page_template" => $row["page_template"]);
				}
				else
				{
					$treeArr[$counter] = array("current" => "0","page_lang" => $hp["page_lang"],"page_key" => $row["page_key"],"page_headline" => $row["page_headline"],"page_navigation" => $row["page_navigation"],"page_title" => $row["page_title"],"page_path" => $link_path,"page_template" => $row["page_template"]);
				}
				$counter++;
			}
		}
		return $treeArr;
	}

	public function getStatus($page_status)
	{
		switch ($page_status)
		{
	 	   	case "0":
				return "Released";
	        break;
	 	   	case "1":
				return "Registered User";
	        break;
	 	   	case "2":
				return "Locked";
	        break;
		}
	}	
	
	public function getTemplateKey($template_key)
	{
		$param = array("template_key" => $template_key);
		$query = "SELECT * FROM ".$this->prefix."template WHERE template_key = :template_key";
		return $this->db->row($query,$param);
	}	
	
	public function getTemplatePage($template_key)
	{
		$param = array("template_key" => $template_key);
		$query = "SELECT template_name FROM ".$this->prefix."template WHERE template_key = :template_key";
		$template = $this->db->row($query,$param);
		$template_name = $template["template_name"];
		$param = array("page_template" => $template_name);
		$query = "SELECT page_key FROM ".$this->prefix."page WHERE page_template = :page_template";
		return $this->db->count($query,$param);
	}	
	
	public function getGroups()
	{
		$query = "SELECT * FROM ".$this->prefix."group ORDER BY group_order DESC";
		return $this->db->select($query);
	}	
	
	public function getReplacings()
	{
		$query = "SELECT re_key,re_name,re_value FROM ".$this->prefix."replacing ORDER BY re_name";
		return $this->db->select($query);
	}	
	
	public function isStage($page_key,$block)
	{
		$param = array("stage_edit" => $block,"page_key" => $page_key);
		$query = "SELECT page_key FROM ".$this->prefix."stage WHERE stage_edit = :stage_edit AND page_key = :page_key";
		if ($this->db->count($query,$param) == 0)
		{
			return false;
		}
		else
		{
			return true;
		}
	}

	public function stagingOutput($block,$subpage = 0)
	{
		global $page;
		if ($subpage != 0)
		{
			$pageedit = $this->getPageKey($subpage);
		}
		else
		{
			$pageedit = $page;
		}
		$param = array("stage_edit" => $block,"page_key" => $pageedit["page_key"]);
		$query = "SELECT stage_key,stage_input FROM ".$this->prefix."stage WHERE stage_edit = :stage_edit AND page_key = :page_key";
		$resArr = $this->db->row($query,$param);
		if (sizeof($resArr) == 1)
		{
			return $pageedit[$block];
		}
		else
		{
			return $resArr["stage_input"];
		}
	}

	public function nextPage()
	{
		global $page;
		$account_status = 0;
		$access = "";
		$parent_key = $page["page_parent"];
		$page_order = $page["page_order"] - 1;
		if (empty($_GET["export"]))
		{
			$account_status = $_SESSION["account_group"];
			if ($_SESSION["account_group"] == 1)
			{
				$account_access = $_SESSION["account_access"];
				$access = " AND (page_access <= :account_access)";
				$param = array("page_parent" => $parent_key,"page_order" => $page_order,"account_status" => $account_status,"page_access" => $account_access);
			}
			else
			{
				$param = array("page_parent" => $parent_key,"page_order" => $page_order,"account_status" => $account_status);
			}
		}
		else
		{
			$param = array("page_parent" => $parent_key,"page_order" => $page_order,"account_status" => $account_status);
		}
		$query = "SELECT * FROM ".$this->prefix."page WHERE (page_parent = :page_parent) AND (page_order = :page_order) AND (page_status <= :account_status) $access";
		return $this->db->row($query,$param);
	}

	public function backPage()
	{
		global $page;
		$account_status = 0;
		$access = "";
		$parent_key = $page["page_parent"];
		$page_order = $page["page_order"] + 1;
		if (empty($_GET["export"]))
		{
			$account_status = $_SESSION["account_group"];
			if ($_SESSION["account_group"] == 1)
			{
				$account_access = $_SESSION["account_access"];
				$access = " AND (page_access <= :account_access)";
				$param = array("page_parent" => $parent_key,"page_order" => $page_order,"account_status" => $account_status,"page_access" => $account_access);
			}
			else
			{
				$param = array("page_parent" => $parent_key,"page_order" => $page_order,"account_status" => $account_status);
			}
		}
		else
		{
			$param = array("page_parent" => $parent_key,"page_order" => $page_order,"account_status" => $account_status);
		}
		$query = "SELECT * FROM ".$this->prefix."page WHERE (page_parent = :page_parent) AND (page_order = :page_order) AND (page_status <= :account_status) $access";
		return $this->db->row($query,$param);
	}	
	
	public function getPrimary()
	{
		global $path;
		$prim = new Structure();
		$prim->key = $path[0]["page_key"];
		$prim->checkhide = true;
		$prim->setwebsite = true;
		$prim->checkexternal = true;
		$prim->navigation = true;
		$primary = $prim->getStructure();
		$tempArr = array();
		foreach ($primary as $row)
		{
			$row["current"] = 0;
			if (isset($path[1]))
			{
				if ($row["page_key"] == $path[1]["page_key"])
				{
					$row["current"] = 1;
				}
			}
			array_push($tempArr,$row);
		}
		return $tempArr;			
	}
	
	public function getSiblings()
	{
		global $page,$path;
		if ($page["page_parent"] == 0)
		{
			$key = $path[0]["page_key"];
		}
		else
		{
			$key = $page["page_parent"];
		}
		$sib = new Structure();
		$sib->key = $key;
		$sib->checkhide = true;
		$sib->setwebsite = true;
		$sib->checkexternal = true;
		$sib->navigation = true;
		$siblings = $sib->getStructure();
		$tempArr = array();
		foreach ($siblings as $row)
		{
			$row["current"] = 0;
			if ($row["page_key"] == $page["page_key"])
			{
				$row["current"] = 1;
			}
			array_push($tempArr,$row);
		}
		return $tempArr;			
	}
	
	public function getChildren()
	{
		global $page;
		$child = new Structure();
		$child->key = $page["page_key"];
		$child->checkhide = true;
		$child->setwebsite = true;
		$child->checkexternal = true;
		$child->navigation = true;
		$children = $child->getStructure();
		$tempArr = array();
		foreach ($children as $row)
		{
			$row["current"] = 0;
			array_push($tempArr,$row);
		}
		return $tempArr;		
	}
	
	public function stringPool($name,$select)
	{
		$param = array("str_name" => $name,"str_select" => $select);
		$query = "SELECT * FROM ".$this->prefix."stringpool WHERE str_name = :str_name AND str_select = :str_select";
		$resArr = $this->db->row($query,$param);
		if (sizeof($resArr) == 1)
		{
			return "";
		}
		else
		{
			return $resArr["str_value"];
		}
	}	
	
	public function dbInclude($template_name)
	{
		$param = array("template_name" => $template_name);
		$query = "SELECT template_source FROM ".$this->prefix."template where template_name = :template_name";
		$temp_arr = $this->db->row($query,$param);
		if ($temp_arr["template_source"] != "")
		{
			return "?>".$temp_arr["template_source"]."<?";
		}
		else
		{
			return "";
		}
	}

	public function getFolder($page_file)
	{
		$folders = explode("/",$page_file);
		$str_folder = "";
		for ($i = 0; $i < sizeof($folders) - 1; $i++)
		{
			$str_folder .= $folders[$i]."/";
		}
		return $str_folder;
	}
	
	public function dbIncludePHPModule($template_name)
	{
		$param = array("template_name" => $template_name);
		$query = "SELECT template_source FROM ".$this->prefix."template where template_name = :template_name";
		$temp_arr = $this->db->row($query,$param);
		if (empty($_GET["export"]))
		{
			if ($temp_arr["template_source"] != "")
			{
				return "?>".$temp_arr["template_source"]."<?";
			}
			else
			{
				return "";
			}
		}
		else
		{
			echo $temp_arr["template_source"];
			return "";
		}
	}
	
	public function textareaEncode($html_code)
	{
	    $from = array("<",">","&nbsp;");
	    $to = array("&lt;","&gt;","&amp;nbsp;");
	    $html_code = str_replace($from, $to, $html_code);
	    return $html_code;
	}	
	
	public function outputDate($str)
	{
		$outArr = array();
		if (strlen($str) == 8)
		{
			$outArr[0] = substr($str,0,4);
			$outArr[1] = substr($str,4,2);
			$outArr[2] = substr($str,6,2);
		}
		else
		{
			$outArr[0] = "";
			$outArr[1] = "";
			$outArr[2] = "";
		}
		return $outArr;
	}	

	public function outputPageDate($str)
	{
		$outArr = array();
		if (strlen($str) == 10)
		{
			$outArr = explode("-",$str);
			if (sizeof($outArr) != 3)
			{
				$str = $page_date = date("Y-m-d");
				$outArr = explode("-",$str);
			}
		}
		else
		{
			$str = $page_date = date("Y-m-d");
			$outArr = explode("-",$str);
		}
		return $outArr;
	}
		
	public function formatDate($str,$sep)
	{
		$dateArr = $this->outputDate($str);
		$day = $dateArr[2];
		$month = $dateArr[1];
		$year = $dateArr[0];
		if (($day != "") && ($month != "") && ($year != ""))
		{
			return $day.$sep.$month.$sep.$year;
		}
		else
		{
			return "";
		}
	}	
	
	public function getFolderPath($key,$mode = true)
	{
		$retStr = "/";
		$retArr = array();
		$param = array("folder_key" => $key);
		$query = "SELECT * FROM ".$this->prefix."filepool WHERE folder_key = :folder_key";
		$foArr = $this->db->row($query,$param);
		$foParent = $foArr["folder_parent"];
		$foName = $foArr["folder_name"];
		$foNameOld = $foName;
		while ($foParent != 0)
		{
			array_push($retArr,$foName);
			$param = array("folder_key" => $foParent);
			$query = "SELECT * FROM ".$this->prefix."filepool WHERE folder_key = :folder_key";
			$foArr = $this->db->row($query,$param);
			$foParent = $foArr["folder_parent"];
			$foName = $foArr["folder_name"];
		}
		$retArr = array_reverse($retArr);
		$retStr .= implode("/",$retArr);
		if (strlen($retStr) > 1)
		{
			$retStr .= "/";
		}
		if (!$mode)
		{
			$retStr = substr($retStr,0,strlen($retStr) - strlen($foNameOld) - 1);
		}
		return $retStr;
	}	

	public function oeNameToSafe($name, $maxlen=250)
	{
		$noalpha = '�?É�?ÓÚ�?áéíóúýÂÊÎÔÛâêîôûÀÈÌÒÙàèìòùÄË�?ÖÜäëïöüÿÃãÕõÅåÑñÇç@°ºª';
		$alpha = 'AEIOUYaeiouyAEIOUaeiouAEIOUaeiouAEIOUaeiouyAaOoAaNnCcaooa';
		$name = substr($name, 0, $maxlen);
		$name = strtr($name, $noalpha, $alpha);
		return strtolower(preg_replace('/[^a-zA-Z0-9,._\+\()\-]/', '_', $name));
	} 
	
	public function convertPath($rel_input)
	{
		$abs_input = $_SERVER["SCRIPT_FILENAME"];
		$pos = strpos($abs_input,"\\");
		if ($pos === false) 
		{
			$splitter = "/";
		}
		else
		{
			$splitter = "\\";
		}
		$rel_input_arr = explode("/",$rel_input);
		$rel_input_arr_new = explode("/",$rel_input);
	
		$abs_input_arr = explode($splitter,$abs_input);
		$abs_input_arr = array_slice($abs_input_arr, 0, sizeof($abs_input_arr) - 1);
	
		foreach ($rel_input_arr as $value1)
		{
			if ($value1 == "..")
			{
				$rel_input_arr_new = array_slice($rel_input_arr_new, 1, sizeof($abs_input_arr));
				$abs_input_arr = array_slice($abs_input_arr, 0, sizeof($abs_input_arr) - 1);
			}
		}
		$abs_input = implode($splitter,$abs_input_arr).$splitter.implode($splitter,$rel_input_arr_new);
		if (is_dir($abs_input))
		{
			return $abs_input;
		}
		else
		{
			return "";
		}
	}	

	public function htmlEncode($input)
	{
		global $site_encoding;
		if ($site_encoding == "iso-8859-1")
		{
			$output = $input;
			$output = str_replace("<","[oe_lt]",$output);
			$output = str_replace(">","[oe_gt]",$output);
			$output = htmlentities($output);
			$output = str_replace("[oe_lt]","<",$output);
			$output = str_replace("[oe_gt]",">",$output);
			$output = str_replace("&quot;",'"',$output);
			$output = str_replace("&amp;",'&',$output);
		}
		else
		{
			$output = $input;
		}
		return $output;
	}
	
	public function getFile($page_file)
	{
		$file_name = str_replace("/", "_", $page_file);
		if (substr($file_name, 0, 1) == "_")
		{
			$file_name = substr($file_name, 1);
		}
		return $file_name;
	}
	
	public function getSearchresult($searchstring,$field_name,$stepsize,$step)
	{
		$search = array();
		$query = "SELECT * FROM ".$this->prefix."page WHERE (LOWER($field_name) like LOWER('%$searchstring%')) AND (page_status <= ".$_SESSION["account_group"].") ORDER BY page_headline";
		$result = $this->db->search($query);
		$maxsearch = mysql_num_rows($result);
		$counter = 1;
		while ($row = mysql_fetch_array($result))
		{
			if (($counter >= (($step - 1) * $stepsize)) && ($counter < (($step * $stepsize)) + 1))
			{
				$search[$counter] = array("search_max" => $maxsearch,"search_counter" => $counter,"page_headline" => $row["page_headline"],"page_title" => $row["page_title"],"page_path" => $row["page_path"],$field_name => $row[$field_name]);
			}
			$counter++;
		}
		return $search;
	}

	public function formatInternaltime($time_str)
	{
		if ($time_str != "")
		{
			$year = substr($time_str,0,4);
			$month = substr($time_str,4,2);
			$day = substr($time_str,6,2);
			$hour = substr($time_str,8,2);
			$minute = substr($time_str,10,2);
			$second = substr($time_str,12,2);
			return $day.".".$month.".".$year." ".$hour.":".$minute.":".$second;
		}
		else
		{
			return "";
		}
	}
	
	public function createThumb($infile,$outfile,$maxw,$maxh)
	{
		if ($this->user->isAdmin() && ($infile != ""))
		{
			if (file_exists($outfile))
			{
				unlink($outfile);
			}
			$path_parts = pathinfo($infile);
			$extension = strtolower($path_parts["extension"]);
			if (($extension == "png") || ($extension == "jpg") || ($extension == "gif"))
			{
				if (($extension == "png") && ($this->set->checkGD("PNG") == 1))
				{
					$this->create_thumbnail($infile,$outfile,$maxw,$maxh);	
				}
				if (($extension == "jpg") && ($this->set->checkGD("JPG") == 1))
				{
					$this->create_thumbnail($infile,$outfile,$maxw,$maxh);	
				}
				if (($extension == "gif") && ($this->set->checkGD("GIF") == 1))
				{
					$this->create_thumbnail($infile,$outfile,$maxw,$maxh);	
				}
			}
		}
	}
	
	public function writeRss()
	{
		global $page,$site_encoding;
		header("Content-type: text/xml");
		$param = array("page_key" => $page["page_key"]);
		$query = "SELECT * FROM ".$this->prefix."rss WHERE page_key = :page_key";
		$rssArr = $this->db->row($query,$param);
		if (sizeof($rssArr) > 1)
		{
			$rss_title = $rssArr["rss_title"];
			$rss_description = $rssArr["rss_description"];
			$rss_size = $rssArr["rss_size"];
		}
		else
		{
			$rss_title = $page["page_title"];
			$rss_description = $page["page_description"];
			$rss_size = $_GET["rss"];
		}
		$counter = 0;
		$sub = new Structure();
		$sub->key = $page["page_key"];
		$subpages = $sub->getStructure();
		?>
<?= "<"; ?>?xml version="1.0" encoding="<?= $site_encoding; ?>" ?<?= ">"; ?>
<rss version="2.0">
<channel>
<title><?= $rss_title; ?></title>
<description><![CDATA[<?= html_entity_decode($rss_description); ?>]]></description>
<generator><?= $this->set->getSystemHtml(); ?></generator>
		<? 
		foreach ($subpages as $row) 
		{ 
			if ($counter < $rss_size)
			{
		?>        
<item>
<title><![CDATA[<?= html_entity_decode($row["page_title"]); ?>]]></title>
<link><?= $this->set->getSiteUrl(); ?>/website.php?id=<?= $row["page_path"]; ?></link>
<description><![CDATA[<?= html_entity_decode($row["page_description"]); ?>]]></description>
</item>
		<? 
				$counter++;
			}
		} 
		?>
</channel>
</rss>
		<?		
	}
	
	public function writeInclude()
	{
		global $page;
		echo file_get_contents($page["page_include"]);
	}
	
	public function getThumbnailInfo()
	{
		$query = "SELECT * FROM ".$this->prefix."thumbnails";
		return $this->db->select($query);
	}	
}
?>