<?php

/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * @package openEngine
 * @author Stephan Raabe
 */

class Session
{
	private $set;
	private $db;
	private $prefix;
	private $sessiontimeout;
	
	public function Session()
	{
		global $oe_set,$oe_db,$db_praefix,$oe_session_timeout;
		$this->set = $oe_set;
		$this->db = $oe_db;
		$this->prefix = $db_praefix;
		$this->sessiontimeout = $oe_session_timeout;
	}
	
	public function init()
	{
		if (!isset($_GET["export"]))
		{
			SecureSession::init($this->sessiontimeout,"/",$this->set->getSessionId());
			$this->checkInitiated();
			$this->checkSiteurl();
			$this->checkUseragent();
		}		
	}
	
	private function checkInitiated()
	{
		if (!isset($_SESSION["initiated"]))
		{
			$_SESSION["initiated"] = 1;
			$this->setGuest();
		}
	}
	
	private function checkSiteurl()
	{
		if ($_SESSION["site_url_key"] != $this->set->getSiteUrl())
		{
			$this->setGuest();
		}
	}
	
	private function checkUseragent()
	{
		if (empty($_SESSION["account_group"]))
		{
			$this->setGuest();
		}
	}
	
	public function setGuest()
	{
		$query = "SELECT * FROM ".$this->prefix."account WHERE account_group = 0";
		$resArr = $this->db->row($query);
		foreach (array_keys($resArr) as $value)
		{
			$_SESSION[$value] = $resArr[$value];
		}		
		$_SESSION["site_url_key"] = $this->set->getSiteUrl();
	}
	
	public function checkSessionTimeout()
	{
		$current = microtime(true);
		if (isset($_SESSION["oe_sessiontimeout"]))
		{
			if (($current - $_SESSION["oe_sessiontimeout"]) > $this->set->getSessionTimeout())
			{
				session_unset();
				session_destroy();
				$this->unsetOeCookie();
				$this->init();
				SecureSession::open();
				if (isset($_GET["id"]))
				{
					$path = "?id=".$_GET["id"]."&";
				}
				else
				{
					$path = "?";
				}
				header(HeaderFilter::filter("Location: website.php".$path."admin=login&timeout=true"));
			}
			else
			{
				$_SESSION["oe_sessiontimeout"] = $current;
			}
		}
		else
		{
			$_SESSION["oe_sessiontimeout"] = microtime(true);
		}
	}
	
	public function setOeCookie()
	{
		global $oe_https;
		setcookie("token",$_SESSION["token"],null,"/",null,$oe_https);
	}

	public function unsetOeCookie()
	{
		global $oe_https;
		setcookie("token","",null,"/",null,$oe_https);
	}
	
	public function checkAuthorSession()
	{
		// if ($_SESSION["account_randomkey"] != $_COOKIE["account_randomkey"]) { die("ERROR: Permission denied"); }
	}
}
?>